@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -87,18 +87,19 @@
 #include <QtDataVisualization/qlogvalue3daxisformatter.h>
 #include <QtDataVisualization/q3dbars.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qbardataproxy.h>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
 #include <qsurfacedataproxy.h>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
