@@ -6,8 +6,8 @@ from textwrap import dedent
 __all__ = list("Qt" + body for body in
     "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLWidgets;Positioning;NetworkAuth;Qml;Quick;Quick3D;QuickControls2;QuickWidgets;RemoteObjects;Scxml;Sensors;SerialPort;StateMachine;Charts;Svg;SvgWidgets;DataVisualization;Bluetooth;UiTools;WebChannel;WebEngineCore;WebEngineWidgets;WebEngineQuick;WebSockets;DBus;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
     .split(";"))
-__version__ = "6.2.3"
-__version_info__ = (6, 2, 3, "", "")
+__version__ = "6.2.4"
+__version_info__ = (6, 2, 4, "", "")
 
 
 def _additional_dll_directories(package_dir):
@@ -23,7 +23,7 @@ def _additional_dll_directories(package_dir):
     # is executed in the build directory. We need libpyside and Qt in addition.
     shiboken6 = Path(root).parent / 'shiboken6' / 'libshiboken'
     if not shiboken6.is_dir():
-        raise ImportError(shiboken6 + ' does not exist')
+        raise ImportError(str(shiboken6) + ' does not exist')
     result = [shiboken6, root / 'libpyside']
     for path in os.environ.get('PATH').split(';'):
         if path:
